@@ -23,6 +23,7 @@ class Collection:
     def __init__(self, api_key, collection_name):
         self.__api_key__ = api_key
         self.__collection_name__ = collection_name
+        self.__dict = dict()
 
     def __create(self, doc_id, doc):
         data = {
@@ -85,68 +86,68 @@ class Collection:
         return self.__read(key)
 
     def __repr__(self):
-        self.__dict__ = self.__list()
-        return repr(self)
+        self.__dict = self.__list()
+        return repr(self.__list())
 
     def __len__(self):
-        self.__dict__ = self.__list()
-        return len(self.__dict__)
+        self.__dict = self.__list()
+        return len(self.__dict)
 
     def __delitem__(self, key):
         return self.__delete(key)
 
     def clear(self):
-        self.__dict__ = self.__list()
-        for key in self.__dict__.keys():
+        self.__dict = self.__list()
+        for key in self.__dict.keys():
             self.__delete(key)
 
     def copy(self):
-        self.__dict__ = self.__list()
-        return self.__dict__.copy()
+        self.__dict = self.__list()
+        return self.__dict.copy()
 
     def has_key(self, k):
-        self.__dict__ = self.__list()
-        return k in self.__dict__ or k in self
+        self.__dict = self.__list()
+        return k in self.__dict
 
     def update(self, *args, **kwargs):
-        self.__dict__ = self.__list()
-        self.__dict__.update(*args, **kwargs)
-        for key, value in self.__dict__.items():
+        self.__dict = self.__list()
+        self.__dict.update(*args, **kwargs)
+        for key, value in self.__dict.items():
             self.__update(key, value)
 
     def keys(self):
-        self.__dict__ = self.__list()
-        return self.__dict__.keys()
+        self.__dict = self.__list()
+        return self.__dict.keys()
 
     def values(self):
-        self.__dict__ = self.__list()
-        return self.__dict__.values()
+        self.__dict = self.__list()
+        return self.__dict.values()
 
     def items(self):
-        self.__dict__ = self.__list()
-        return self.__dict__.items()
+        self.__dict = self.__list()
+        return self.__dict.items()
 
     def pop(self, key, default_key):
-        self.__dict__ = self.__list()
-        true_key = key if key in self.__dict__ else default_key if default_key in self.__dict__ else None
+        self.__dict = self.__list()
+        true_key = key if key in self.__dict else default_key if default_key in self.__dict else None
         if true_key:
-            item = self.__dict__[true_key]
+            item = self.__dict[true_key]
             self.__delete(true_key)
             return item
         else:
             raise KeyError(key)
 
     def __contains__(self, item):
-        self.__dict__ = self.__list()
-        return item in self.__dict__
+        self.__dict = self.__list()
+        return str(item) in self.__dict
 
     def __iter__(self):
-        self.__dict__ = self.__list()
-        return iter(self.__dict__)
+        self.__dict = self.__list()
+        return iter(self.__dict)
 
-    # def __str__(self):
-    #     self.__dict__ = self.__list()
-    #     return str(repr(self.__dict__))
+    def __str__(self):
+        self.__dict = self.__list()
+        return str(repr(self.__dict))
 
 
 def parse(json_data):
